@@ -1,8 +1,7 @@
 /*
 **  OSSP cfg - Configuration Parsing
-**  Copyright (c) 2002-2004 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2002-2004 The OSSP Project (http://www.ossp.org/)
-**  Copyright (c) 2002-2004 Cable & Wireless (http://www.cw.com/)
+**  Copyright (c) 2002-2006 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2002-2006 The OSSP Project (http://www.ossp.org/)
 **
 **  This file is part of OSSP cfg, a configuration parsing
 **  library which can be found at http://www.ossp.org/pkg/lib/cfg/.
@@ -110,7 +109,7 @@
 #define CFG_RING_ELEM(type) \
     struct { type *next; type *prev; }
 #define CFG_RING_SENTINEL(hp, type, field) \
-    (type *)((char *)(hp) - ((size_t)(&((type *)0)->field)))
+    (type *)(void *)((char *)(hp) - ((size_t)(&((type *)0)->field)))
 #define CFG_RING_INIT(hp, type, field) \
     do { CFG_RING_FIRST((hp)) = CFG_RING_SENTINEL((hp), type, field); \
          CFG_RING_LAST((hp))  = CFG_RING_SENTINEL((hp), type, field); } while (0)
@@ -238,7 +237,7 @@ cfg_grid_seg_create(
 
     /* initialize first segment */
     CFG_RING_ELEM_INIT(seg, gs_link);
-    seg->gs_tile_base = (cfg_grid_tile_t *)((char *)seg + seg_top_size);
+    seg->gs_tile_base = (cfg_grid_tile_t *)(void *)((char *)seg + seg_top_size);
     seg->gs_tile_num = tile_num;
     CFG_LIST_ELEM_INIT(seg->gs_tile_base, gt_link);
     CFG_LIST_INIT(&seg->gs_tile_free_list);
@@ -248,7 +247,7 @@ cfg_grid_seg_create(
     /* initialize free tile list in first segment */
     tile = CFG_LIST_FIRST(&seg->gs_tile_free_list);
     for (i = 0; i < seg->gs_tile_free_num-1; i++) {
-        CFG_LIST_NEXT(tile, gt_link) = (cfg_grid_tile_t *)((char *)tile+tile_size);
+        CFG_LIST_NEXT(tile, gt_link) = (cfg_grid_tile_t *)(void *)((char *)tile+tile_size);
         tile = CFG_LIST_NEXT(tile, gt_link);
     }
     CFG_LIST_NEXT(tile, gt_link) = NULL;
